import sys
import os

from setuptools import setup
from setuptools.command.test import test as TestCommand


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as buf:
        return buf.read()


class PyTest(TestCommand):
    user_options = [('pytest-args=', 'a', "Arguments to pass to py.test")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.pytest_args = []

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.pytest_args)
        sys.exit(errno)


setup(name='larigira-filters',
      version='1.1.0',
      description='some filters for larigira',
      long_description=read('README.rst'),
      author='boyska',
      author_email='piuttosto@logorroici.org',
      license='AGPL',
      packages=['larigira.filters'],
      install_requires=['mutagen'],
      tests_require=['pytest-timeout==1.0', 'py>=1.4.29', 'pytest==3.0', ],
      cmdclass={'test': PyTest},
      zip_safe=False,
      include_package_data=True,
      entry_points={
          'larigira.eventfilter': [
              'maxwait = larigira.filters.base:maxwait',
              'percentwait = larigira.filters.base:percentwait',
          ],
      },
      classifiers=[
          "License :: OSI Approved :: GNU Affero General Public License v3",
          "Programming Language :: Python :: 3",
      ]
      )
